# Security Policy
The security surface area of Hamilton should be pretty small in comparison to other projects. But to get a better mark on Github, we're including this policy file for completeness.

## Supported Versions

We currently only support the latest version of Hamilton that's been released.

| Version | Supported          |
| ------- | ------------------ |
| Latest  | :white_check_mark: |

## Reporting a Vulnerability

To report a vulnerability, use github's vulnerability reporting feature to private flag an issue to contributors.
